// Required libraries
#include <avr/io.h>
#include <util/delay.h>
#include <avr/interrupt.h>
#include "uart.h"

#define CLK  PD5  // CLK -> pin 5 
#define DIO  PD4  // DIO -> pin 4 


#define set_bit(ADDRESS,BIT) (ADDRESS |= (1<<BIT))
#define clear_bit(ADDRESS,BIT) (ADDRESS &= ~(1<<BIT))


#define LEFT_START_STOP_PIN PD2 // Button for the left team
#define RIGHT_START_STOP_PIN PD3 // Button for the right team
#define RESTART_PIN PD6 // Button for the right team





volatile uint8_t count_left = 0;  // Counter for the left displays
volatile uint8_t count_right = 0; // Counter for the right displays



// External interrupt 0 (button for the left team)
ISR (INT0_vect)
{
	

    _delay_ms(10);
    if(bit_is_clear(PIND, LEFT_START_STOP_PIN)){
        // Increase left count and reset if it reaches 100
        count_left++;
		
        if (count_left >= 100) count_left = 0;
    }
    _delay_ms(150);
}

// External interrupt 1 (button for the right team)
ISR (INT1_vect)
{
    _delay_ms(10);
    if(bit_is_clear(PIND, RIGHT_START_STOP_PIN)){
        // Increase right count and reset if it reaches 100
        count_right++;
        if (count_right >= 100) count_right = 0;
    }
    _delay_ms(150);
}


int main(void){
    
    clear_bit(DDRD, CLK);  // Set CLK as input
    set_bit(PORTD, CLK);   // CLK as input pull-up on
    
    clear_bit(DDRD, DIO);  // Set DIO as input
    set_bit(PORTD, DIO);   // DIO as input pull-up o
    
    clear_bit(DDRD, LEFT_START_STOP_PIN);   // Set LEFT_START_STOP_PIN as input
    set_bit(PORTD, LEFT_START_STOP_PIN);    // LEFT_START_STOP_PIN as input pull-up on
    
    clear_bit(DDRD, RIGHT_START_STOP_PIN);  // Set RIGHT_START_STOP_PIN as input
    set_bit(PORTD, RIGHT_START_STOP_PIN);   // RIGHT_START_STOP_PIN as input pull-up on
	
	clear_bit(DDRD, RESTART_PIN);  // set RESET_PIN as input
	set_bit(PORTD, RESTART_PIN);  // RESET_PIN as input pull-up on
	
    uint8_t data[] = { 0, 0, 0, 0 };
    set_segments(data, 4, 0);

    
    EIMSK = 0b00000011; // Enable INT0, INT1
    EICRA = 0b00001010;       // Detect falling edge on both pins
    
    sei();  // Enable interrupts
    

    
    while (1) {
		if (bit_is_clear(PIND, RESTART_PIN)) {
			// Perform reset operation
			
			count_left = 0; // Reset the left count
			count_right = 0; // Reset the right count
			
			}

			// Display left count on left two displays and right count on right two displays
			
			display_number_segment(count_right, 0, 2, 2);
			
			display_number_segment(count_left, 0, 2, 0);

    }
    
    return 0;
}